# flake8: noqa


fetch_payload = {
    "current_page": 1,
    "data": [
        {
            "sender_id": "ACME Key",
            "status": "unblock",
            "company": "ACME",
            "usecase": None,
            "country": None,
            "created_at": "2021-03-29 16:51:53",
        },
        {
            "sender_id": "ACME Alert",
            "status": "unblock",
            "company": "ACME",
            "usecase": None,
            "country": None,
            "created_at": "2021-03-29 16:51:09",
        },
        {
            "sender_id": "ACME Wall",
            "status": "unblock",
            "company": "ACME",
            "usecase": None,
            "country": None,
            "created_at": "2021-03-29 16:50:38",
        },
        {
            "sender_id": "Hooli",
            "status": "unblock",
            "company": "Hooli",
            "usecase": None,
            "country": None,
            "created_at": "2021-03-26 13:19:16",
        },
        {
            "sender_id": "Google",
            "status": "unblock",
            "company": None,
            "usecase": None,
            "country": None,
            "created_at": "2021-01-19 17:41:30",
        },
        {
            "sender_id": "Facebook",
            "status": "unblock",
            "company": None,
            "usecase": None,
            "country": None,
            "created_at": "2021-01-19 17:41:14",
        },
    ],
    "first_page_url": "https://api.ng.termii.com/api/sender-id?page=1",
    "from": 1,
    "last_page": 47,
    "last_page_url": "https://api.ng.termii.com/api/sender-id?page=47",
    "next_page_url": "https://api.ng.termii.com/api/sender-id?page=2",
    "path": "https://api.ng.termii.com/api/sender-id",
    "per_page": 10,
    "prev_page_url": None,
    "to": 15,
    "total": 704,
}


request_payload = {
    "code": "ok",
    "message": "Sender Id requested. You will be  contacted by your account manager.",
}
