FETCH_SENDER_ID = (
    "{TERMII_ENDPOINT_URL}/sender-id?api_key={TERMII_API_KEY}&page={data_page}"
)
REQUEST_SENDER_ID = "{TERMII_ENDPOINT_URL}/api/sender-id/request"
SEND_MESSAGE = "{TERMII_ENDPOINT_URL}/api/sms/send"
SEND_BULK_MESSAGE = "{TERMII_ENDPOINT_URL}/api/sms/send/bulk"
SEND_FROM_AUTOGENERATED = "{TERMII_ENDPOINT_URL}/api/sms/number/send"
